Tutorial
========

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    notebooks/localjoincounts.ipynb
    notebooks/LOSH.ipynb
    notebooks/geosilhouettes.ipynb
    notebooks/adbscan_berlin_example.ipynb
    notebooks/shape-measures.ipynb
    notebooks/spatial_autocorrelation_for_areal_unit_data.ipynb
    notebooks/multivariable_moran.ipynb
    notebooks/correlogram.ipynb
    notebooks/topo.ipynb
